@@ -1,5 +1,7 @@
 /*
- * WMND configuration data definitions
+ * cfgdata: WMND configuration data
+ * Copyright(c) 2001-2008 by wave++ "Yuri D'Elia" <wavexx@users.sf.net>
+ * Distributed under GNU GPL (v2 or above) WITHOUT ANY WARRANTY.
  */
 
 /* local header */
@@ -34,7 +36,7 @@ struct pair_strstr pss_defcon[] =
   {"scroll",          "10",      0},
   {"avg_steps",       "1",       0},
   {"binary_scale",    "no",      0},
-  {"interface_name",  "%first",  0}, 
+  {"interface_name",  "%first",  0},
   {"use_long_names",  "no",      0},
   {"show_max_values", "yes",     0},
   {"use_max_history", "no",      0},
@@ -48,5 +50,11 @@ struct pair_strstr pss_defcon[] =
   {"fixed_max",       "0",       0},
   {"display",         NULL,      0},
   {"geometry",        NULL,      0},
+  {"debug",           "no",      0},
+#ifdef USE_TREND
+  {"trend_flags",     "",        0},
+  {"trend_update",    "yes",     0},
+  {"trend_history",   "58",      0},
+#endif
   {NULL,              NULL,      0}
 };
