@@ -1,10 +1,15 @@
 /*
- * WMND configuration data
+ * cfgdata: WMND configuration data
+ * Copyright(c) 2001-2008 by wave++ "Yuri D'Elia" <wavexx@users.sf.net>
+ * Distributed under GNU GPL (v2 or above) WITHOUT ANY WARRANTY.
  */
 
 #ifndef CFGDATA_H
 #define CFGDATA_H
 
+#include "config.h"
+
+
 /* configuration enums */
 struct pair_strint
 {
@@ -27,4 +32,3 @@ struct pair_strstr
 extern struct pair_strstr pss_defcon[];
 
 #endif
-
